# Summary

- [Introduction](./README.md)
- [Usage](./Usage.md)
- [API](./api/README.md)
  - [Static Analysis](./api/static_analysis.md)
  - [API](./api/api.md)
  - [SlithIR](./api/SlithIR.md)
  - [SSA](./api/SlithIR-SSA.md)
  - [Data dependency](./api/Data-dependency.md)
  - [JSON output](./api/JSON-output.md)
- [Detectors](./detectors/Detector-Documentation.md)
  - [Detectors](./detectors/Detector-Documentation.md)
  - [Adding a detector](./detectors/Adding-a-new-detector.md)
- [Printers](./printers/Printer-documentation.md)
- [Tools](./tools/README.md)
  - [Adding a new tool](./tools/Adding-a-new-utility.md)
  - [Code Similarity](./tools/Code-Similarity-Detector.md)
  - [Contract Flattening](./tools/Contract-Flattening.md)
  - [Documentation](./tools/Documentation.md)
  - [Doctor](./tools/Doctor.md)
  - [ERC Conformance](./tools/ERC-Conformance.md)
  - [Interface](./tools/Interface.md)
  - [Mutator](./tools/Mutator.md)
  - [Path Finding Utility](./tools/Path-Finding-Utility.md)
  - [Property Generation](./tools/Property-generation.md)
  - [Read Storage](./tools/ReadStorage.md)
  - [Format](./tools/Slither-format.md)
  - [Upgradeability checks](./tools/Upgradeability-Checks.md)
- [Tutorials](./tutorials/README.md)
  - [Exercise 1](./tutorials/exercise1.md)
  - [Exercise 2](./tutorials/exercise2.md)
  - [Exercise 3](./tutorials/exercise3.md)
